@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: bug_actiongroup.php,v 1.38 2004/11/30 15:41:35 thraxisp Exp $
+	# $Id: bug_actiongroup.php,v 1.47 2005/06/16 02:26:48 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -14,9 +14,9 @@
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'bug_api.php' );
 ?>
 <?php auth_ensure_user_authenticated() ?>
@@ -24,25 +24,49 @@
 	helper_begin_long_process();
 
 	$f_action	= gpc_get_string( 'action' );
+	$f_custom_field_id = gpc_get_int( 'custom_field_id', 0 );
 	$f_bug_arr	= gpc_get_int_array( 'bug_arr', array() );
 
+	$t_custom_group_actions = config_get( 'custom_group_actions' );
+
+	foreach( $t_custom_group_actions as $t_custom_group_action ) {
+		if ( $f_action == $t_custom_group_action['action'] ) {
+			require_once( $t_custom_group_action['action_page'] );
+			exit;
+		}
+	}
+
 	$t_failed_ids = array();
 
+	if ( 0 != $f_custom_field_id ) {
+		$t_custom_field_def = custom_field_get_definition( $f_custom_field_id );
+	}
+
 	foreach( $f_bug_arr as $t_bug_id ) {
 		bug_ensure_exists( $t_bug_id );
-		$t_status = bug_get_field( $t_bug_id, 'status' );
+		$t_bug = bug_get( $t_bug_id, true );
+
+		if( $t_bug->project_id != helper_get_current_project() ) {
+			# in case the current project is not the same project of the bug we are viewing...
+			# ... override the current project. This to avoid problems with categories and handlers lists etc.
+			$g_project_override = $t_bug->project_id;
+			# @@@ (thraxisp) the next line goes away if the cache was smarter and used project
+			config_flush_cache(); # flush the config cache so that configs are refetched
+		}
+
+		$t_status = $t_bug->status;
 
 		switch ( $f_action ) {
 
 		case 'CLOSE':
 			if ( access_can_close_bug( $t_bug_id ) &&
-					( $t_status < CLOSED ) && 
+					( $t_status < CLOSED ) &&
 					bug_check_workflow($t_status, CLOSED) ) {
 				bug_close( $t_bug_id );
 			} else {
 				if ( ! access_can_close_bug( $t_bug_id ) ) {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
-				}else{
+				} else {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_status' );
 				}
 			}
@@ -82,9 +106,11 @@
 			} else {
 				$t_assign_status = $t_status;
 			}
+			# check that new handler has rights to handle the issue, and
+			#  that current user has rights to assign the issue
 			$t_threshold = access_get_status_threshold( $t_assign_status, bug_get_field( $t_bug_id, 'project_id' ) );
 			if ( access_has_bug_level( $t_threshold , $t_bug_id, $f_assign ) &&
-				 access_has_bug_level( config_get( 'handle_bug_threshold' ), $t_bug_id ) &&
+				 access_has_bug_level( config_get( 'update_bug_assign_threshold', config_get( 'update_bug_threshold' ) ), $t_bug_id ) &&
 					bug_check_workflow($t_status, $t_assign_status )	) {
 				bug_assign( $t_bug_id, $f_assign );
 			} else {
@@ -99,13 +125,13 @@
 		case 'RESOLVE':
 			$t_resolved_status = config_get( 'bug_resolved_status_threshold' );
 			if ( access_has_bug_level( access_get_status_threshold( $t_resolved_status, bug_get_field( $t_bug_id, 'project_id' ) ), $t_bug_id ) &&
-				 		( $t_status < $t_resolved_status ) && 
+				 		( $t_status < $t_resolved_status ) &&
 						bug_check_workflow($t_status, $t_resolved_status ) ) {
 				$f_resolution = gpc_get_int( 'resolution' );
 				$f_fixed_in_version = gpc_get_string( 'fixed_in_version', '' );
 				bug_resolve( $t_bug_id, $f_resolution, $f_fixed_in_version );
 			} else {
-				if ( ( $t_status < $t_resolved_status ) && 
+				if ( ( $t_status < $t_resolved_status ) &&
 						bug_check_workflow($t_status, $t_resolved_status ) ) {
 					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
 				} else {
@@ -137,6 +163,20 @@
 			}
 			break;
 
+		case 'UP_CATEGORY':
+			$f_category = gpc_get_string( 'category' );
+			$t_project = bug_get_field( $t_bug_id, 'project_id' );
+			if ( access_has_bug_level( config_get( 'update_bug_threshold' ), $t_bug_id ) ) {
+				if ( category_exists( $t_project, $f_category ) ) {
+					bug_set_field( $t_bug_id, 'category', $f_category );
+				} else {
+					$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_category' );
+				}
+			} else {
+				$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
+			}
+			break;
+
 		case 'VIEW_STATUS':
 			if ( access_has_bug_level( config_get( 'change_view_status_threshold' ), $t_bug_id ) ) {
 				$f_view_status = gpc_get_int( 'view_status' );
@@ -146,6 +186,26 @@
 			}
 			break;
 
+		case 'SET_STICKY':
+			if ( access_has_bug_level( config_get( 'set_bug_sticky_threshold' ), $t_bug_id ) ) {
+				$f_sticky = bug_get_field( $t_bug_id, 'sticky' );
+				// The new value is the inverted old value
+				bug_set_field( $t_bug_id, 'sticky', !$f_sticky );
+			} else {
+				$t_failed_ids[$t_bug_id] = lang_get( 'bug_actiongroup_access' );
+			}
+			break;
+
+		case 'CUSTOM':
+			if ( 0 === $f_custom_field_id ) {
+				trigger_error( ERROR_GENERIC, ERROR );
+			}
+
+			$t_form_var = "custom_field_$f_custom_field_id";
+			$t_custom_field_value = gpc_get_custom_field( $t_form_var, $t_custom_field_def['type'], null );
+			custom_field_set_value( $f_custom_field_id, $t_bug_id, $t_custom_field_value );
+			break;
+
 		default:
 			trigger_error( ERROR_GENERIC, ERROR );
 		}
@@ -156,15 +216,15 @@
 	if ( count( $t_failed_ids ) > 0 ) {
 		html_page_top1();
 		html_page_top2();
-		
+
 		echo '<div align="center">';
 		foreach( $t_failed_ids as $t_id => $t_reason ) {
 			printf("<p> %s: %s </p>\n", string_get_bug_view_link( $t_id ), $t_reason);
 		}
 		print_bracket_link( $t_redirect_url, lang_get( 'proceed' ) );
 		echo '</div>';
-		
-		html_page_bottom1( __FILE__ );	
+
+		html_page_bottom1( __FILE__ );
 	} else {
 		print_header_redirect( $t_redirect_url );
 	}
