@@ -6,7 +6,7 @@
 	# See the files README and LICENSE for details
 
 	# --------------------------------------------------------
-	# $Id: bug_sponsorship_list_view_inc.php,v 1.10.8.1 2005/09/22 10:53:57 vboctor Exp $
+	# $Id: bug_sponsorship_list_view_inc.php,v 1.12.4.1 2005/09/22 11:01:05 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -107,6 +107,9 @@
 					echo $t_date_added . ': ';
 					print_user( $t_sponsorship->user_id );
 					echo ' (' . sponsorship_format_amount( $t_sponsorship->amount ) . ')';
+					if ( access_has_bug_level( config_get( 'handle_sponsored_bugs_threshold' ), $f_bug_id ) ) {
+						echo ' ' . get_enum_element( 'sponsorship', $t_sponsorship->paid );
+					}
 				}
 			}
 		?>
