@@ -6,7 +6,7 @@
 	# See the files README and LICENSE for details
 
 	# --------------------------------------------------------
-	# $Id: bugnote_view_inc.php,v 1.24 2004/11/30 12:17:03 vboctor Exp $
+	# $Id: bugnote_view_inc.php,v 1.30 2005/05/16 12:56:05 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -33,7 +33,7 @@
 	$t_bugnote_order		= current_user_get_pref( 'bugnote_order' );
 
 	# get the bugnote data
-	$query = "SELECT *,date_submitted
+	$query = "SELECT *
 			FROM $t_bugnote_table
 			WHERE bug_id='$f_bug_id' $t_restriction
 			ORDER BY date_submitted $t_bugnote_order";
@@ -47,11 +47,13 @@
 <?php if ( ON == config_get( 'use_javascript' ) ) { ?>
 <div id="bugnotes_closed" style="display: none;">
 <table class="width100" cellspacing="1">
+<tr>
 	<td class="form-title" colspan="2">
-		<a href="" onClick="ToggleDiv( 'bugnotes', g_div_bugnotes ); return false;"
+		<a href="" onclick="ToggleDiv( 'bugnotes', g_div_bugnotes ); return false;"
 		><img border="0" src="images/plus.png" alt="+" /></a>
 		<?php echo lang_get( 'bug_notes_title' ) ?>
 	</td>
+</tr>
 </table>
 </div>
 <?php } ?>
@@ -71,7 +73,7 @@
 <tr>
 	<td class="form-title" colspan="2">
 <?php if ( ON == config_get( 'use_javascript' ) ) { ?>
-		<a href="" onClick="ToggleDiv( 'bugnotes', g_div_bugnotes ); return false;"
+		<a href="" onclick="ToggleDiv( 'bugnotes', g_div_bugnotes ); return false;"
 		><img border="0" src="images/minus.png" alt="-" /></a>
 <?php } ?>
 		<?php echo lang_get( 'bug_notes_title' ) ?>
@@ -132,14 +134,14 @@
 			if ( !bug_is_readonly( $f_bug_id ) ) {
 				if ( ( access_has_bug_level( config_get( 'manage_project_threshold' ), $f_bug_id ) ) ||
 					( ( $v3_reporter_id == $t_user_id ) && ( ON == config_get( 'bugnote_allow_user_edit_delete' ) ) ) ) {
-					print_bracket_link( 'bugnote_edit_page.php?bugnote_id='.$v3_id, lang_get( 'bugnote_edit_link' ) );
-					print_bracket_link( 'bugnote_delete.php?bugnote_id='.$v3_id, lang_get( 'delete_link' ) );
+					print_button( 'bugnote_edit_page.php?bugnote_id='.$v3_id, lang_get( 'bugnote_edit_link' ) );
+					print_button( 'bugnote_delete.php?bugnote_id='.$v3_id, lang_get( 'delete_link' ) );
 					if ( access_has_bug_level( config_get( 'private_bugnote_threshold' ), $f_bug_id ) &&
 						access_has_bug_level( config_get( 'change_view_status_threshold' ), $f_bug_id ) ) {
 						if ( VS_PRIVATE == $v3_view_state ) {
-							print_bracket_link('bugnote_set_view_state.php?private=0&amp;bugnote_id='.$v3_id, lang_get( 'make_public' ));
+							print_button('bugnote_set_view_state.php?private=0&amp;bugnote_id='.$v3_id, lang_get( 'make_public' ));
 						} else {
-							print_bracket_link('bugnote_set_view_state.php?private=1&amp;bugnote_id='.$v3_id, lang_get( 'make_private' ));
+							print_button('bugnote_set_view_state.php?private=1&amp;bugnote_id='.$v3_id, lang_get( 'make_private' ));
 						}
 					}
 				}
@@ -176,7 +178,9 @@
 
 <?php if ( ON == config_get( 'use_javascript' ) ) { ?>
 <script type="text/JavaScript">
+<!--
 	SetDiv( "bugnotes", g_div_bugnotes );
+// -->
 </script>
 <?php } ?>
 
