@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.12 2006/10/29 00:20:29 vboctor Exp $
+	# $Id: config_defaults_inc.php,v 1.283.2.1.2.1.2.1.2.2.2.15 2007/06/30 22:25:05 vboctor Exp $
 	# --------------------------------------------------------
 
 
@@ -23,7 +23,7 @@
 	# In general a value of OFF means the feature is disabled and ON means the
 	# feature is enabled.  Any other cases will have an explanation.
 
-	# For more details see http://manual.mantisbugtracker.com/
+	# For more details see http://www.mantisbt.org/manual/
 
 	################################
 	# Mantis Database Settings
@@ -103,7 +103,7 @@
 	$g_core_path			= $g_absolute_path . 'core' . DIRECTORY_SEPARATOR;
 
 	# Used to link to manual for User Documentation.
-	$g_manual_url = 'http://manual.mantisbugtracker.com/';
+	$g_manual_url = 'http://www.mantisbt.org/manual/';
 
 	#############################
 	# Web Server
@@ -314,7 +314,7 @@
 	#############################
 
 	# --- version variables -----------
-	$g_mantis_version		= '1.0.6';
+	$g_mantis_version		= '1.0.8';
 	$g_show_version			= ON;
 
 	################################
