@@ -1,43 +1,47 @@
 <?php
 
 /**
-  V3.50 19 May 2003  (c) 2000-2003 John Lim (jlim@natsoft.com.my). All rights reserved.
-  Released under both BSD license and Lesser GPL library license. 
-  Whenever there is any discrepancy between the two licenses, 
+  V4.60 24 Jan 2005  (c) 2000-2005 John Lim (jlim@natsoft.com.my). All rights reserved.
+  Released under both BSD license and Lesser GPL library license.
+  Whenever there is any discrepancy between the two licenses,
   the BSD license will take precedence.
-	
+
   Set tabs to 4 for best viewing.
- 
+
 */
 
+// security - hide paths
+if (!defined('ADODB_DIR')) die();
+
 class ADODB2_ibase extends ADODB_DataDict {
-	
+
 	var $databaseType = 'ibase';
 	var $seqField = false;
-	
- 	
+
+
  	function ActualType($meta)
 	{
 		switch($meta) {
 		case 'C': return 'VARCHAR';
+		case 'XS':
 		case 'XL':
-		case 'X': return 'VARCHAR(4000)'; 
-		
+		case 'X': return 'VARCHAR(4000)';
+
 		case 'C2': return 'VARCHAR'; // up to 32K
 		case 'X2': return 'VARCHAR(4000)';
-		
+
 		case 'B': return 'BLOB';
-			
+
 		case 'D': return 'DATE';
 		case 'T': return 'TIMESTAMP';
-		
+
 		case 'L': return 'SMALLINT';
 		case 'I': return 'INTEGER';
 		case 'I1': return 'SMALLINT';
 		case 'I2': return 'SMALLINT';
 		case 'I4': return 'INTEGER';
 		case 'I8': return 'INTEGER';
-		
+
 		case 'F': return 'DOUBLE PRECISION';
 		case 'N': return 'DECIMAL';
 		default:
@@ -50,15 +54,15 @@ class ADODB2_ibase extends ADODB_DataDict {
 		if ($this->debug) ADOConnection::outp("AlterColumnSQL not supported");
 		return array();
 	}
-	
-	
+
+
 	function DropColumnSQL($tabname, $flds)
 	{
 		if ($this->debug) ADOConnection::outp("DropColumnSQL not supported");
 		return array();
 	}
-	
+
 }
 
 
-?>
\ No newline at end of file
+?>
