@@ -1,29 +1,29 @@
 <?php
-/** 
- * @version V3.50 19 May 2003 (c) 2000-2003 John Lim (jlim@natsoft.com.my). All rights reserved.
- * Released under both BSD license and Lesser GPL library license. 
- * Whenever there is any discrepancy between the two licenses, 
- * the BSD license will take precedence. 
+/**
+ * @version V4.50 6 July 2004 (c) 2000-2005 John Lim (jlim@natsoft.com.my). All rights reserved.
+ * Released under both BSD license and Lesser GPL library license.
+ * Whenever there is any discrepancy between the two licenses,
+ * the BSD license will take precedence.
  *
  * Set tabs to 4 for best viewing.
- * 
+ *
  * Latest version is available at http://php.weblogs.com
  *
  * Requires PHP4.01pl2 or later because it uses include_once
 */
 
 /*
-	Filter all fields and all rows in a recordset and returns the 
+	Filter all fields and all rows in a recordset and returns the
 	processed recordset. We scroll to the beginning of the new recordset
 	after processing.
-	
+
 	We pass a recordset and function name to RSFilter($rs,'rowfunc');
 	and the function will be called multiple times, once
 	for each row in the recordset. The function will be passed
 	an array containing one row repeatedly.
-	
-	Example: 
- 	
+
+	Example:
+
 	// ucwords() every element in the recordset
 	function do_ucwords(&$arr,$rs)
 	{
@@ -36,17 +36,26 @@
 function &RSFilter($rs,$fn)
 {
 	if ($rs->databaseType != 'array') {
+		if (!$rs->connection) return false;
+
 		$rs = &$rs->connection->_rs2rs($rs);
 	}
 	$rows = $rs->RecordCount();
 	for ($i=0; $i < $rows; $i++) {
-		$fn($rs->_array[$i],$rs);
+		if (is_array ($fn)) {
+        	$obj = $fn[0];
+        	$method = $fn[1];
+        	$obj->$method ($rs->_array[$i],$rs);
+      } else {
+			$fn($rs->_array[$i],$rs);
+      }
+
 	}
 	if (!$rs->EOF) {
 		$rs->_currentRow = 0;
 		$rs->fields = $rs->_array[0];
 	}
-	
+
 	return $rs;
 }
-?>
\ No newline at end of file
+?>
