@@ -5,25 +5,18 @@
 //+----------------------------------------------------------------------+
 //| Copyright (c) 1992-2003 Michael Wimmer                               |
 //+----------------------------------------------------------------------+
-/*| This program is free software; you can redistribute it and/or modify |
-  | it under the terms of the GNU General Public License as published by |
-  | the Free Software Foundation; either version 2 of the License, or    |
-  | (at your option) any later version.                                  |
-  |                                                                      |
-  | This program is distributed in the hope that it will be useful,      |
-  | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
-  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
-  | GNU General Public License for more details.                         |
-  |                                                                      |
-  | You should have received a copy of the GNU General Public License    |
-  | along with this program; if not, write to the Free Software          |
-  | Foundation, Inc., 51 Franklin St, Fifth Floor,                       |
-  | Boston, MA  02110-1301  USA                                          |
+//| I don't have the time to read through all the licences to find out   |
+//| what the exactly say. But it's simple. It's free for non commercial  |
+//| projects, but as soon as you make money with it, i want my share :-) |
+//| (License : Free for non-commercial use)                              |
+//|                                                                      |
+//| *** LICENSE CHANGED TO GPL, see news post by owner at: *****         |
+//| http://sourceforge.net/forum/forum.php?forum_id=694707               |
 //+----------------------------------------------------------------------+
 //| Authors: Michael Wimmer <flaimo@gmx.net>                             |
 //+----------------------------------------------------------------------+
 //
-// $Id$
+// $Id: class.RSSBuilder.inc.php,v 1.4.12.1 2007/05/12 06:21:54 vboctor Exp $
 
 /**
 * @package RSSBuilder
@@ -1331,25 +1324,23 @@ class RSSBuilder extends RSSBase {
 				break;
 		} // end switch
 	} // end function
-	/**#@-*/
-
-	/**#@+
-	* @return void
-	* @access public
-	* @uses createOutput()
-	*/
 	/**
 	* echos the output
 	*
 	* use this function if you want to directly output the rss stream
 	*
 	* @desc echos the output
+	* @return void
+	* @access public
+	* @uses createOutput()
 	*/
 	function outputRSS($version = '') {
 		if (!isset($this->output)) {
 			$this->createOutput($version);
 		} // end if
-		header ('content-type: text/xml');
+
+		# Mantis: text/xml -> application/xml
+		header ('content-type: application/xml');
 		header('Content-Disposition: inline; filename=rss_' . str_replace(' ','',$this->title) . '.xml');
 		$this->output = '<?xml version="1.0" encoding="' . $this->encoding . '"?>' . "\n" .
 						'<!--  RSS generated by Flaimo.com RSS Builder [' .  date('Y-m-d H:i:s')  .']  --> ' . $this->output;
