@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: print_api.php,v 1.143.6.1.4.1.2.3 2006/09/23 06:30:21 vboctor Exp $
+	# $Id: print_api.php,v 1.143.6.1.4.1.2.4 2007/03/06 07:00:33 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -782,7 +782,7 @@
 				$t_custom_field_def = custom_field_get_definition( $t_custom_field_id );
 				$t_command_id = 'custom_field_' . $t_custom_field_id;
 				$t_command_caption = sprintf( lang_get( 'actiongroup_menu_update_field' ), lang_get_defaulted( $t_custom_field_def['name'] ) );
-				$commands[$t_command_id] = $t_command_caption;
+				$commands[$t_command_id] = string_display( $t_command_caption );
 			}
 		}
 
