@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: summary_api.php,v 1.33 2004/10/20 01:11:01 narcissus Exp $
+	# $Id: summary_api.php,v 1.42.6.1 2006/01/08 14:55:50 thraxisp Exp $
 	# --------------------------------------------------------
 
 	### Summary printing API ###
@@ -27,31 +27,25 @@
 	# for each enum setting
 	# The enum field name is passed in through $p_enum
 	function summary_print_by_enum( $p_enum_string, $p_enum ) {
-		$t_mantis_bug_table = config_get( 'mantis_bug_table' );
-
-		$t_arr = explode_enum_string( $p_enum_string );
-		$enum_count = count( $t_arr );
-
 		$t_project_id = helper_get_current_project();
 		$t_user_id = auth_get_current_user_id();
 
-		#checking if it's a per project statistic or all projects
-		if ( ALL_PROJECTS == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$t_project_filter = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$t_project_filter = '1=1';
-			}
-		} else {
-			$t_project_filter = " project_id='$t_project_id'";
+		$t_project_filter = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $t_project_filter ) {
+			return;
 		}
+		
+		$t_filter_prefix = config_get( 'bug_count_hyperlink_prefix' );
+		$t_arr = explode_enum_string( $p_enum_string );
+		$enum_count = count( $t_arr );
 
-		$query = "SELECT status, $p_enum
+		$t_mantis_bug_table = config_get( 'mantis_bug_table' );
+		$t_status_query = ( 'status' == $p_enum ) ? '' : ' ,status ';		  
+		$query = "SELECT COUNT(id) as count, $p_enum $t_status_query 
 				FROM $t_mantis_bug_table
 				WHERE $t_project_filter
-				ORDER BY $p_enum";
+				GROUP BY $p_enum $t_status_query 
+				ORDER BY $p_enum $t_status_query";
 		$result = db_query( $query );
 
 		$t_last_value = -1;
@@ -60,7 +54,7 @@
 		$t_bugs_closed = 0;
 		$t_bugs_total = 0;
 
-		$t_resolved_val = RESOLVED;
+		$t_resolved_val = config_get( 'bug_resolved_status_threshold' );
 		$t_closed_val = CLOSED;
 
 		while ( $row = db_fetch_array( $result ) ) {
@@ -70,29 +64,40 @@
 				$t_bug_link = '';
 				switch ( $p_enum ) {
 					case 'status':
-						$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_status=' . $t_last_value;
+						$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_status=' . $t_last_value;
 						break;
 					case 'severity':
-						$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_severity=' . $t_last_value;
+						$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_severity=' . $t_last_value;
 						break;
 					case 'resolution':
-						$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_resolution=' . $t_last_value;
+						$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_resolution=' . $t_last_value;
 						break;
 					case 'priority':
-						# Currently no filtering by priority :(
-						$t_bug_link = '';
+						$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_priority=' . $t_last_value;
 						break;
 				}
 
 				if ( !is_blank( $t_bug_link ) ) {
 					if ( 0 < $t_bugs_open ) {
 						$t_bugs_open = $t_bug_link . '&amp;hide_status=' . RESOLVED . '">' . $t_bugs_open . '</a>';
+					} else {
+						if ( ( 'status' == $p_enum ) && ( $t_last_value >= $t_resolved_val ) ) {
+							$t_bugs_open = '-';
+						}
 					}
 					if ( 0 < $t_bugs_resolved ) {
 						$t_bugs_resolved = $t_bug_link . '&amp;show_status=' . RESOLVED . '&amp;hide_status=' . CLOSED . '">' . $t_bugs_resolved . '</a>';
+					} else {
+						if ( ( 'status' == $p_enum ) && ( ( $t_last_value < $t_resolved_val ) || ( $t_last_value >= $t_closed_val ) ) ) {
+							$t_bugs_resolved = '-';
+						}
 					}
 					if ( 0 < $t_bugs_closed ) {
 						$t_bugs_closed = $t_bug_link . '&amp;show_status=' . CLOSED . '&amp;hide_status=">' . $t_bugs_closed . '</a>';
+					} else {
+						if ( ( 'status' == $p_enum ) && ( $t_last_value < $t_closed_val ) ){
+							$t_bugs_closed = '-';
+						}
 					}
 					if ( 0 < $t_bugs_total ) {
 						$t_bugs_total = $t_bug_link . '&amp;hide_status=">' . $t_bugs_total . '</a>';
@@ -107,17 +112,13 @@
 				$t_bugs_total		= 0;
 			}
 
-			$t_bugs_total++;
-			switch( $row['status'] ) {
-				case $t_resolved_val:
-					$t_bugs_resolved++;
-					break;
-				case $t_closed_val:
-					$t_bugs_closed++;
-					break;
-				default:
-					$t_bugs_open++;
-					break;
+			$t_bugs_total += $row['count'];
+			if ( $t_closed_val <= $row['status'] ) {
+				$t_bugs_closed += $row['count'];
+			} else if ( $t_resolved_val <= $row['status'] ) {
+				$t_bugs_resolved += $row['count'];
+			} else {
+				$t_bugs_open += $row['count'];
 			}
 			$t_last_value = $row[$p_enum];
 		}
@@ -127,29 +128,40 @@
 			$t_bug_link = '';
 			switch ( $p_enum ) {
 				case 'status':
-					$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_status=' . $t_last_value;
+					$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_status=' . $t_last_value;
 					break;
 				case 'severity':
-					$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_severity=' . $t_last_value;
+					$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_severity=' . $t_last_value;
 					break;
 				case 'resolution':
-					$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_resolution=' . $t_last_value;
+					$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_resolution=' . $t_last_value;
 					break;
 				case 'priority':
-					# Currently no filtering by priority :(
-					$t_bug_link = '';
+					$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;show_priority=' . $t_last_value;
 					break;
 			}
 
 			if ( !is_blank( $t_bug_link ) ) {
 				if ( 0 < $t_bugs_open ) {
 					$t_bugs_open = $t_bug_link . '&amp;hide_status=' . RESOLVED . '">' . $t_bugs_open . '</a>';
+				} else {
+					if ( ( 'status' == $p_enum ) && ( $t_last_value >= $t_resolved_val ) ) {
+						$t_bugs_open = '-';
+					}
 				}
 				if ( 0 < $t_bugs_resolved ) {
 					$t_bugs_resolved = $t_bug_link . '&amp;show_status=' . RESOLVED . '&amp;hide_status=' . CLOSED . '">' . $t_bugs_resolved . '</a>';
+					} else {
+						if ( ( 'status' == $p_enum ) && ( ( $t_last_value < $t_resolved_val ) || ( $t_last_value >= $t_closed_val ) ) ) {
+							$t_bugs_resolved = '-';
+					}
 				}
 				if ( 0 < $t_bugs_closed ) {
 					$t_bugs_closed = $t_bug_link . '&amp;show_status=' . CLOSED . '&amp;hide_status=">' . $t_bugs_closed . '</a>';
+					} else {
+						if ( ( 'status' == $p_enum ) && ( $t_last_value < $t_closed_val ) ){
+							$t_bugs_closed = '-';
+						}
 				}
 				if ( 0 < $t_bugs_total ) {
 					$t_bugs_total = $t_bug_link . '&amp;hide_status=">' . $t_bugs_total . '</a>';
@@ -170,17 +182,9 @@
 		$t_project_id = helper_get_current_project();
 		$t_user_id = auth_get_current_user_id();
 
-		#checking if it's a per project statistic or all projects
-		if ( ALL_PROJECTS == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
 		$query = "SELECT COUNT(*)
@@ -215,25 +219,20 @@
 	function summary_print_by_developer() {
 		$t_mantis_bug_table = config_get( 'mantis_bug_table' );
 		$t_mantis_user_table = config_get( 'mantis_user_table' );
+
 		$t_project_id = helper_get_current_project();
 		$t_user_id = auth_get_current_user_id();
 
-		if ( ALL_PROJECTS == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
-		$query = "SELECT handler_id, status
+		$query = "SELECT COUNT(id) as count, handler_id, status
 				FROM $t_mantis_bug_table
 				WHERE handler_id>0 AND $specific_where
-				ORDER BY handler_id";
+				GROUP BY handler_id, status
+				ORDER BY handler_id, status";
 		$result = db_query( $query );
 
 		$t_last_handler = -1;
@@ -273,17 +272,14 @@
 				$t_bugs_total = 0;
 			}
 
-			$t_bugs_total++;
-
-			switch( $v_status ) {
-				case $t_resolved_val:	$t_bugs_resolved++;
-										break;
-				case $t_closed_val:		$t_bugs_closed++;
-										break;
-				default:				$t_bugs_open++;
-										break;
+			$t_bugs_total += $v_count;
+			if ( $t_closed_val <= $row['status'] ) {
+				$t_bugs_closed += $v_count;
+			} else if ( $t_resolved_val <= $row['status'] ) {
+				$t_bugs_resolved += $v_count;
+			} else {
+				$t_bugs_open += $v_count;
 			}
-
 			$t_last_handler = $v_handler_id;
 		}
 
@@ -317,16 +313,9 @@
 		$t_project_id = helper_get_current_project();
 		$t_user_id = auth_get_current_user_id();
 
-		if ( ALL_PROJECTS == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
 		$query = "SELECT reporter_id, COUNT(*) as num
@@ -338,9 +327,11 @@
 
 		while ( $row = db_fetch_array( $result ) ) {
 			$v_reporter_id = $row['reporter_id'];
-			$query = "SELECT status FROM $t_mantis_bug_table
+			$query = "SELECT COUNT(id) as count, status FROM $t_mantis_bug_table
 					WHERE reporter_id=$v_reporter_id
-					AND $specific_where";
+					AND $specific_where
+					GROUP BY status
+					ORDER BY status";
 			$result2 = db_query( $query );
 
 			$last_reporter = -1;
@@ -353,24 +344,19 @@
 			$t_closed_val = CLOSED;
 
 			while ( $row2 = db_fetch_array( $result2 ) ) {
-				$t_bugs_total++;
-
-				switch( $row2['status'] ) {
-					case $t_resolved_val:	$t_bugs_resolved++;
-											break;
-					case $t_closed_val:		$t_bugs_closed++;
-											break;
-					default:				$t_bugs_open++;
-											break;
-				}
+                $t_bugs_total += $row2['count'];
+                if ( $t_closed_val <= $row2['status'] ) {
+                    $t_bugs_closed += $row2['count'];
+                } else if ( $t_resolved_val <= $row2['status'] ) {
+                    $t_bugs_resolved += $row2['count'];
+                } else {
+                    $t_bugs_open += $row2['count'];
+                }
 			}
 
 			if ( 0 < $t_bugs_total ) {
 				$t_user = user_get_name( $v_reporter_id );
 
-				$result3 = db_query( $query );
-				$row3 = db_fetch_array( $result3 );
-
 				$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;reporter_id=' . $v_reporter_id;
 				if ( 0 < $t_bugs_open ) {
 					$t_bugs_open = $t_bug_link . '&amp;hide_status=' . RESOLVED . '">' . $t_bugs_open . '</a>';
@@ -399,22 +385,17 @@
 		$t_project_id = helper_get_current_project();
 		$t_user_id = auth_get_current_user_id();
 
-		if ( ALL_PROJECTS == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
+		$t_project_query = ( ON == $t_summary_category_include_project ) ? 'project_id, ' : '';
 
-		$query = "SELECT project_id, category, status
+		$query = "SELECT COUNT(id) as count, $t_project_query category, status
 				FROM $t_mantis_bug_table
 				WHERE category>'' AND $specific_where
-				ORDER BY project_id, category, status";
+				GROUP BY $t_project_query category, status
+				ORDER BY $t_project_query category, status";
 
 		$result = db_query( $query );
 
@@ -434,13 +415,7 @@
 			if ( ( $v_category != $last_category ) && ( $last_category != -1 ) ) {
 				$label = $last_category;
 				if ( ( ON == $t_summary_category_include_project ) && ( ALL_PROJECTS == $t_project_id ) ) {
-					$query = "SELECT name
-							FROM $t_mantis_project_table
-							WHERE id=$last_project";
-					$result2 = db_query( $query );
-					$row2 = db_fetch_array( $result2 );
-
-					$label = sprintf( '[%s] %s', $row2['name'], $label );
+					$label = sprintf( '[%s] %s', project_get_name( $last_project ), $label );
 				}
 
 				$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_category=' . $last_category;
@@ -457,7 +432,7 @@
 					$t_bugs_total = $t_bug_link . '&amp;hide_status=">' . $t_bugs_total . '</a>';
 				}
 
-				summary_helper_print_row( string_attribute($label), $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
+				summary_helper_print_row( $label, $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
 
 				$t_bugs_open = 0;
 				$t_bugs_resolved = 0;
@@ -465,34 +440,25 @@
 				$t_bugs_total = 0;
 			}
 
-			$t_bugs_total++;
-
-			switch( $v_status ) {
-				case $t_resolved_val:
-										$t_bugs_resolved++;
-										break;
-				case $t_closed_val:
-										$t_bugs_closed++;
-										break;
-				default:
-										$t_bugs_open++;
-										break;
-			}
+            $t_bugs_total += $row['count'];
+            if ( $t_closed_val <= $row['status'] ) {
+                $t_bugs_closed += $row['count'];
+            } else if ( $t_resolved_val <= $row['status'] ) {
+                $t_bugs_resolved += $row['count'];
+            } else {
+                $t_bugs_open += $row['count'];
+            }
 
 			$last_category = $v_category;
-			$last_project = $v_project_id;
+			if ( ( ON == $t_summary_category_include_project ) && ( ALL_PROJECTS == $t_project_id ) ) {
+                $last_project = $v_project_id;
+            }
 		}
 
 		if ( 0 < $t_bugs_total ) {
 			$label = $last_category;
 			if ( ( ON == $t_summary_category_include_project ) && ( ALL_PROJECTS == $t_project_id ) ) {
-				$query = "SELECT name
-						FROM $t_mantis_project_table
-						WHERE id=$last_project";
-				$result2 = db_query( $query );
-				$row2 = db_fetch_array( $result2 );
-
-				$label = sprintf( '[%s] %s', $row2['name'], $label );
+				$label = sprintf( '[%s] %s', project_get_name( $last_project ), $label );
 			}
 
 			$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;show_category=' . $last_category;
@@ -511,87 +477,79 @@
 				}
 			}
 
-			summary_helper_print_row( string_attribute($label), $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
+			summary_helper_print_row( $label, $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
 		}
 	}
 	# --------------------
 	# print bug counts by project
-	function summary_print_by_project() {
-		$t_mantis_bug_table = config_get( 'mantis_bug_table' );
+	function summary_print_by_project( $p_projects = null, $p_level = 0, $p_cache = null ) {
+		$t_mantis_bug_table 	= config_get( 'mantis_bug_table' );
 		$t_mantis_project_table = config_get( 'mantis_project_table' );
 
 		$t_project_id = helper_get_current_project();
-		$t_user_id = auth_get_current_user_id();
 
-		# This function only works when "all projects" is selected
-		if ( ALL_PROJECTS != $t_project_id ) {
-			return;
-		}
-		
-		# Only projects to which the user have access
-		$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-		if ( count( $t_accessible_projects_array ) > 0 ) {
-			$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-		} else {
-			$specific_where = '1=1';
-		}
-
-		$query = "SELECT project_id, status
-				FROM $t_mantis_bug_table
-				WHERE $specific_where
-				ORDER BY project_id";
-		$result = db_query( $query );
-
-		$t_last_project = -1;
-		$t_bugs_open = 0;
-		$t_bugs_resolved = 0;
-		$t_bugs_closed = 0;
-		$t_bugs_total = 0;
-
-		$t_resolved_val = RESOLVED;
-		$t_closed_val = CLOSED;
-
-		while ( $row = db_fetch_array( $result ) ) {
-			extract( $row, EXTR_PREFIX_ALL, 'v' );
-
-			if ( ( $v_project_id != $t_last_project ) && ( -1 != $t_last_project ) ) {
-				$query = "SELECT name
-						FROM $t_mantis_project_table
-						WHERE id=$t_last_project";
-				$result2 = db_query( $query );
-				$row2 = db_fetch_array( $result2 );
-				summary_helper_print_row( $row2['name'], $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
-
-				$t_bugs_open = 0;
-				$t_bugs_resolved = 0;
-				$t_bugs_closed = 0;
-				$t_bugs_total = 0;
+		if ( null == $p_projects ) {
+			if ( ALL_PROJECTS == $t_project_id ) {
+				$p_projects = current_user_get_accessible_projects();
+			} else {
+				$p_projects = Array( $t_project_id );
 			}
-
-			$t_bugs_total++;
-
-			switch( $v_status ) {
-				case $t_resolved_val:
-										$t_bugs_resolved++;
-										break;
-				case $t_closed_val:
-										$t_bugs_closed++;
-										break;
-				default:
-										$t_bugs_open++;
-										break;
-			}
-
-			$t_last_project = $v_project_id;
 		}
 
-		if ( 0 < $t_bugs_total ) {
-			$query = "SELECT name
-					FROM $t_mantis_project_table
-					WHERE id=$t_last_project";
-			$result2 = db_query( $query );
-			$row2 = db_fetch_array( $result2 );
-			summary_helper_print_row( $row2['name'], $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
+		# Retrieve statistics one time to improve performance.
+		if ( null === $p_cache ) {
+			$query = "SELECT project_id, status, COUNT( status ) AS count
+					FROM $t_mantis_bug_table
+					GROUP BY project_id, status";
+
+			$result = db_query( $query );
+			$p_cache = Array();
+
+			$t_resolved_val = RESOLVED;
+			$t_closed_val = CLOSED;
+
+			while ( $row = db_fetch_array( $result ) ) {
+				extract( $row, EXTR_PREFIX_ALL, 'v' );
+                if ( $t_closed_val <= $v_status ) {
+                    if ( isset( $p_cache[ $v_project_id ][ 'closed'   ] ) ) {
+                        $p_cache[ $v_project_id ][ 'closed'   ]  += $v_count;
+                    } else {
+                        $p_cache[ $v_project_id ][ 'closed'   ]  = $v_count;
+                    }
+                } else if ( $t_resolved_val <= $v_status ) {
+                    if ( isset( $p_cache[ $v_project_id ][ 'resolved' ] ) ) {
+                        $p_cache[ $v_project_id ][ 'resolved' ]  += $v_count;
+                    } else {
+                        $p_cache[ $v_project_id ][ 'resolved' ]  = $v_count;
+                    }
+                } else {
+                    if ( isset( $p_cache[ $v_project_id ][ 'open'     ] ) ) {
+                        $p_cache[ $v_project_id ][ 'open'     ]  += $v_count;
+                    } else {
+                        $p_cache[ $v_project_id ][ 'open'     ]  = $v_count;
+                    }
+                }
+			}
+		}
+
+		foreach ( $p_projects as $t_project ) {
+			$t_name = str_repeat( " ", $p_level ) . project_get_name( $t_project );
+
+			$t_pdata = isset( $p_cache[ $t_project ] ) ? $p_cache[ $t_project ]
+			             : array( 'open' => 0, 'resolved' => 0, 'closed' => 0 );
+
+			$t_bugs_open     = isset( $t_pdata['open'] ) ? $t_pdata['open'] : 0;
+			$t_bugs_resolved = isset( $t_pdata['resolved'] ) ? $t_pdata['resolved'] : 0;
+			$t_bugs_closed   = isset( $t_pdata['closed'] ) ? $t_pdata['closed'] : 0;
+			$t_bugs_total    = $t_bugs_open + $t_bugs_resolved + $t_bugs_closed;
+
+			summary_helper_print_row( $t_name, $t_bugs_open, $t_bugs_resolved, $t_bugs_closed, $t_bugs_total );
+
+			$t_subprojects = current_user_get_accessible_subprojects( $t_project );
+
+			if ( count( $t_subprojects ) > 0 ) {
+				summary_print_by_project( $t_subprojects, $p_level + 1, $p_cache );
+			}
 		}
 	}
 	# --------------------
@@ -612,24 +570,18 @@
 			$c_res_s[$i] = db_prepare_string( $t_res_s[0] );
 		}
 
-		# Checking if it's a per project statistic or all projects
-		if ( 0 == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
 		$specific_where .= ' AND handler_id > 0';
 		# Get all of the bugs and split them up into an array
-		$query = "SELECT handler_id, resolution
+		$query = "SELECT COUNT(id) as count, handler_id, resolution
 				FROM $t_mantis_bug_table
-				WHERE $specific_where";
+				WHERE $specific_where
+				GROUP BY handler_id, resolution
+				ORDER BY handler_id, resolution";
 		$result = db_query( $query );
 
 		$t_handler_res_arr = array();
@@ -642,12 +594,13 @@
 			if ( !isset( $t_handler_res_arr[$t_arr['handler_id']][$t_arr['resolution']] ) ) {
 				$t_handler_res_arr[$t_arr['handler_id']][$t_arr['resolution']] = 0;
 			}
-			$t_handler_res_arr[$t_arr['handler_id']][$t_arr['resolution']]++;
-			$t_handler_res_arr[$t_arr['handler_id']]['total']++;
+			$t_handler_res_arr[$t_arr['handler_id']][$t_arr['resolution']] += $t_arr['count'];
+			$t_handler_res_arr[$t_arr['handler_id']]['total'] += $t_arr['count'];
 
 			$t_arr = db_fetch_array( $result );
 		}
 
+        $t_filter_prefix = config_get( 'bug_count_hyperlink_prefix' );
 		$t_row_count = 0;
 		# We now have a multi dimensional array of users and resolutions, with the value of each resolution for each user
 		foreach( $t_handler_res_arr as $t_handler_id => $t_arr2 ) {
@@ -675,7 +628,7 @@
 
 					PRINT '<td>';
 					if ( 0 < $res_bug_count ) {
-						$t_bug_link = '<a class="subtle" href="' . config_get( 'bug_count_hyperlink_prefix' ) . '&amp;handler_id=' . $t_handler_id;
+						$t_bug_link = '<a class="subtle" href="' . $t_filter_prefix . '&amp;handler_id=' . $t_handler_id;
 						$t_bug_link = $t_bug_link . '&amp;show_resolution=' .  $c_res_s[$j] . '">';
 						PRINT $t_bug_link . $res_bug_count . '</a>';
 					} else {
@@ -726,22 +679,16 @@
 		}
 
 		# Checking if it's a per project statistic or all projects
-		if ( 0 == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
 		# Get all of the bugs and split them up into an array
-		$query = "SELECT reporter_id, resolution
+		$query = "SELECT COUNT(id) as count, reporter_id, resolution
 				FROM $t_mantis_bug_table
-				WHERE $specific_where";
+				WHERE $specific_where
+				GROUP BY reporter_id, resolution";
 		$result = db_query( $query );
 
 		$t_reporter_res_arr = array();
@@ -755,8 +702,8 @@
 			if ( !isset( $t_reporter_res_arr[$t_arr['reporter_id']][$t_arr['resolution']] ) ) {
 				$t_reporter_res_arr[$t_arr['reporter_id']][$t_arr['resolution']] = 0;
 			}
-			$t_reporter_res_arr[$t_arr['reporter_id']][$t_arr['resolution']]++;
-			$t_reporter_bugcount_arr[$t_arr['reporter_id']]++;
+			$t_reporter_res_arr[$t_arr['reporter_id']][$t_arr['resolution']] += $t_arr['count'];
+			$t_reporter_bugcount_arr[$t_arr['reporter_id']] += $t_arr['count'];
 
 			$t_arr = db_fetch_array( $result );
 		}
@@ -824,6 +771,7 @@
 				PRINT '<td>';
 				printf( '% 1.0f%%', ( $t_percent_errors * 100 ) );
 				PRINT '</td>';
+				PRINT '</tr>';
 			}
 		}
 	}	# --------------------
@@ -868,22 +816,16 @@
 		}
 
 		# Checking if it's a per project statistic or all projects
-		if ( 0 == $t_project_id ) {
-			# Only projects to which the user have access
-			$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-			if ( count( $t_accessible_projects_array ) > 0 ) {
-				$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-			} else {
-				$specific_where = '1=1';
-			}
-		} else {
-			$specific_where = " project_id='$t_project_id'";
+		$specific_where = helper_project_specific_where( $t_project_id );
+		if ( ' 1<>1' == $specific_where ) {
+			return;
 		}
 
 		# Get all of the bugs and split them up into an array
-		$query = "SELECT reporter_id, resolution, severity
+		$query = "SELECT COUNT(id) as count, reporter_id, resolution, severity
 				FROM $t_mantis_bug_table
-				WHERE $specific_where";
+				WHERE $specific_where
+				GROUP BY reporter_id, resolution, severity";
 		$result = db_query( $query );
 
 		$t_reporter_ressev_arr = array();
@@ -901,9 +843,9 @@
 			if ( !isset( $t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']][$t_arr['resolution']] ) ) {
 				$t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']][$t_arr['resolution']] = 0;
 			}
-			$t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']][$t_arr['resolution']]++;
-			$t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']]['total']++;
-			$t_reporter_bugcount_arr[$t_arr['reporter_id']]++;
+			$t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']][$t_arr['resolution']] += $t_arr['count'];
+			$t_reporter_ressev_arr[$t_arr['reporter_id']][$t_arr['severity']]['total'] += $t_arr['count'];
+			$t_reporter_bugcount_arr[$t_arr['reporter_id']] += $t_arr['count'];
 
 			$t_arr = db_fetch_array( $result );
 		}
@@ -972,6 +914,7 @@
 				PRINT '<td>';
 				PRINT ( $t_total_severity - $t_total_errors );
 				PRINT '</td>';
+				PRINT '</tr>';
 			}
 		}
 	}
