@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: user_api.php,v 1.106 2005/07/22 15:34:03 thraxisp Exp $
+	# $Id: user_api.php,v 1.106.12.1 2007/03/06 07:00:33 vboctor Exp $
 	# --------------------------------------------------------
 
 	$t_core_dir = dirname( __FILE__ ).DIRECTORY_SEPARATOR;
@@ -182,6 +182,21 @@
 		}
 	}
 
+	# --------------------
+	# Check if the realname is a valid (does not account for uniqueness)
+	# true: valid, false: not valid
+	function user_is_realname_valid( $p_realname ) {
+		return ( !string_contains_scripting_chars( $p_realname ) );
+	}
+
+	# --------------------
+	# Check if the realname is a valid (does not account for uniqueness), if not, trigger an error
+	function user_ensure_realname_valid( $p_realname ) {
+		if ( !user_is_realname_valid( $p_realname ) ) {
+			trigger_error( ERROR_USER_REAL_NAME_INVALID, ERROR );
+		}
+	}
+
 	# --------------------
 	# Check if the username is a valid username (does not account for uniqueness)
 	#  realname can match
@@ -343,6 +358,7 @@
 
 		user_ensure_name_valid( $p_username );
 		user_ensure_name_unique( $p_username );
+		user_ensure_realname_valid( $p_realname );
 		user_ensure_realname_unique( $p_username, $p_realname );
 		email_ensure_valid( $p_email );
 
