@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: login_cookie_test.php,v 1.8.20.1 2005/12/05 12:12:05 vboctor Exp $
+	# $Id: login_cookie_test.php,v 1.8.22.1.6.1 2006/07/22 19:56:20 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -24,5 +24,5 @@
 		$t_redirect_url = 'login_page.php?cookie_error=1';
 	}
 
-	print_header_redirect( $t_redirect_url );
+	print_header_redirect( $t_redirect_url, /* die */ true, /* sanitize */ true );
 ?>
\ No newline at end of file
