@@ -1,12 +1,12 @@
 <?php
 	# Mantis - a php based bugtracking system
 	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
+	# Copyright (C) 2002 - 2005  Mantis Team   - mantisbt-dev@lists.sourceforge.net
 	# This program is distributed under the terms and conditions of the GPL
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: print_all_bug_page.php,v 1.80 2004/07/24 14:31:43 vboctor Exp $
+	# $Id: print_all_bug_page.php,v 1.83.10.1.4.1 2007/03/06 07:00:33 vboctor Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -26,9 +26,10 @@
 	require_once( $t_core_path.'date_api.php' );
 	require_once( $t_core_path.'icon_api.php' );
 	require_once( $t_core_path.'string_api.php' );
-?>
-<?php auth_ensure_user_authenticated( ) ?>
-<?php
+	require_once( $t_core_path.'columns_api.php' );
+
+	auth_ensure_user_authenticated();
+
 	$f_search		= gpc_get_string( 'search', false ); # @@@ need a better default
 	$f_offset		= gpc_get_int( 'offset', 0 );
 
@@ -40,6 +41,9 @@
 	$f_dir		 			= null;
 	$t_project_id 			= 0;
 
+	$t_columns = helper_call_custom_function( 'get_columns_to_view', array( COLUMNS_TARGET_PRINT_PAGE ) );
+	$t_num_of_columns = sizeof( $t_columns );
+
 	# check to see if the cookie exists
 	if ( ! is_blank( $t_cookie_value ) ) {
 
@@ -50,7 +54,7 @@
 
 		$t_setting_arr = explode( '#', $t_cookie_value, 2 );
 		$t_filter_cookie_arr = unserialize( $t_setting_arr[1] );
-	
+
 		$f_highlight_changed 	= $t_filter_cookie_arr['highlight_changed'];
 		$f_sort 				= $t_filter_cookie_arr['sort'];
 		$f_dir		 			= $t_filter_cookie_arr['dir'];
@@ -62,7 +66,7 @@
 	$t_per_page = -1;
 	$t_bug_count = null;
 	$t_page_count = null;
-	
+
 	$result = filter_get_bug_rows( $t_page_number, $t_per_page, $t_page_count, $t_bug_count );
 	$row_count = sizeof( $result );
 
@@ -75,7 +79,7 @@
 
 <table class="width100"><tr><td class="form-title">
 	<div class="center">
-		<?php echo config_get( 'window_title' ) . ' - ' . project_get_name( $t_project_id ); ?>
+		<?php echo string_display( config_get( 'window_title' ) ) . ' - ' . string_display( project_get_name( $t_project_id ) ); ?>
 	</div>
 </td></tr></table>
 
@@ -88,7 +92,7 @@
 <input type="hidden" name="sort" value="<?php echo $f_sort ?>" />
 <input type="hidden" name="dir" value="<?php echo $f_dir ?>" />
 
-<table class="width100">
+<table class="width100" cellpadding="2px">
 <?php
 	#<SQLI> Excel & Print export
 	#$f_bug_array stores the number of the selected rows
@@ -110,7 +114,7 @@
 ?>
 
 <tr>
-	<td colspan="8">
+	<td colspan="<?php echo $t_num_of_columns ?>">
 <?php
 		if ( 'DESC' == $f_dir ) {
 			$t_new_dir = 'ASC';
@@ -148,9 +152,9 @@
 <br />
 
 <form method="post" action="print_all_bug_page.php">
-<table class="width100" cellspacing="1">
+<table class="width100" cellspacing="1" cellpadding="2px">
 <tr>
-	<td class="form-title" colspan="6">
+	<td class="form-title" colspan="<?php echo $t_num_of_columns / 2 + $t_num_of_columns % 2; ?>">
 		<?php echo lang_get( 'viewing_bugs_title' ) ?>
 		<?php
 			if ( $row_count > 0 ) {
@@ -160,137 +164,44 @@
 				$v_start = 0;
 				$v_end   = 0;
 			}
-			PRINT "( $v_start - $v_end )";
+			echo "( $v_start - $v_end )";
 		?>
 	</td>
-	<td class="right" colspan="3">
-		<?php print_bracket_link( 'print_all_bug_options_page.php', lang_get( 'printing_options_link' ) ) ?>
-		<?php print_bracket_link( 'view_all_bug_page.php', lang_get( 'view_bugs_link' ) ) ?>
-		<?php print_bracket_link( 'summary_page.php', lang_get( 'summary' ) ) ?>
+	<td class="right" colspan="<?php echo $t_num_of_columns / 2 ?>">
+		<?php # print_bracket_link( 'print_all_bug_options_page.php', lang_get( 'printing_options_link' ) ) ?>
+		<?php # print_bracket_link( 'view_all_bug_page.php', lang_get( 'view_bugs_link' ) ) ?>
+		<?php # print_bracket_link( 'summary_page.php', lang_get( 'summary' ) ) ?>
 	</td>
 </tr>
 <tr class="row-category">
-	<td class="center" width="2%">&nbsp;</td>
-	<td class="center" width="8%">
-		<?php print_view_bug_sort_link2( 'P', 'priority', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'priority' ) ?>
-	</td>
-	<td class="center" width="8%">
-		<?php print_view_bug_sort_link2( lang_get( 'id' ), 'id', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'id' ) ?>
-	</td>
-	<td class="center" width="3%">
-		#
-	</td>
-	<td class="center" width="12%">
-		<?php print_view_bug_sort_link2( lang_get( 'category' ), 'category', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'category' ) ?>
-	</td>
-	<td class="center" width="10%">
-		<?php print_view_bug_sort_link2( lang_get( 'severity' ), 'severity', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'severity' ) ?>
-	</td>
-	<td class="center" width="10%">
-		<?php print_view_bug_sort_link2( lang_get( 'status' ), 'status', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'status' ) ?>
-	</td>
-	<td class="center" width="12%">
-		<?php print_view_bug_sort_link2( lang_get( 'updated' ), 'last_updated', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'last_updated' ) ?>
-	</td>
-	<td class="center" width="37%">
-		<?php print_view_bug_sort_link2( lang_get( 'summary' ), 'summary', $f_sort, $f_dir ) ?>
-		<?php print_sort_icon( $f_dir, $f_sort, 'summary' ) ?>
-	</td>
+	<?php
+		$t_sort = $f_sort;	// used within the custom function called in the loop (@@@ cleanup)
+		$t_dir = $f_dir;    // used within the custom function called in the loop (@@@ cleanup)
+
+		foreach( $t_columns as $t_column ) {
+			$t_title_function = 'print_column_title';
+			helper_call_custom_function( $t_title_function, array( $t_column, COLUMNS_TARGET_PRINT_PAGE ) );
+		}
+	?>
 </tr>
 <tr>
 	<td class="spacer" colspan="9">&nbsp;</td>
 </tr>
 <?php
 	for( $i=0; $i < $row_count; $i++ ) {
-		# prefix bug data with v_
-		extract( $result[$i], EXTR_PREFIX_ALL, 'v' );
-
-		$v_summary = string_display_links( $v_summary );
-		$t_last_updated = date( $g_short_date_format, $v_last_updated );
+		$t_row = $result[$i];
 
 		# alternate row colors
 		$status_color = helper_alternate_colors( $i, '#ffffff', '#dddddd' );
-
-		# grab the bugnote count
-		$bugnote_count = bug_get_bugnote_count( $v_id );
-
-		# grab the project name
-		$project_name = project_get_field( $v_project_id, 'name' );
-
-		$query = "SELECT MAX( last_modified )
-				FROM $g_mantis_bugnote_table
-				WHERE bug_id='$v_id'";
-		$res2 = db_query( $query );
-		$v_bugnote_updated = db_result( $res2, 0, 0 );
-
-		if ( isset( $t_bug_arr_sort[$i] ) || ( $t_show_flag==0 ) ) {
+		if ( isset( $t_bug_arr_sort[ $t_row['id'] ] ) || ( $t_show_flag==0 ) ) {
+?>
+<tr bgcolor="<?php echo $status_color ?>" border="1">
+<?php
+		foreach( $t_columns as $t_column ) {
+			$t_column_value_function = 'print_column_value';
+			helper_call_custom_function( $t_column_value_function, array( $t_column, $t_row, COLUMNS_TARGET_PRINT_PAGE ) );
+		}
 ?>
-
-<tr>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<input type="checkbox" name="bug_arr[]" value="<?php echo $i ?>" />
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php print_formatted_priority_string( $v_status, $v_priority ) ?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php echo bug_format_id( $v_id ) ?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php
-			if ( $bugnote_count > 0 ){
-				if ( $v_bugnote_updated >
-					strtotime( "-$f_highlight_changed hours" ) ) {
-					PRINT "<span class=\"bold\">$bugnote_count</span>";
-				} else {
-					echo $bugnote_count;
-				}
-			} else {
-				PRINT '&nbsp;';
-			}
-		?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php
-			# Print project name if viewing 'all projects'
-			if ( ALL_PROJECTS == $t_project_id ) {
-				print "[$project_name] <br />";
-			}
-		?>
-		<?php echo $v_category ?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php print_formatted_severity_string( $v_status, $v_severity ) ?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php
-			echo get_enum_element( 'status', $v_status );
-			# print username instead of status
-			if ( $v_handler_id > 0 && ON == config_get( 'show_assigned_names' ) ) {
-				echo '(' . user_get_name( $v_handler_id ) . ')';
-			}
-		?>
-	</td>
-	<td class="print" bgcolor="<?php echo $status_color ?>">
-		<?php
-			if ( $v_last_updated >
-				strtotime( "-$f_highlight_changed hours" ) ) {
-
-				PRINT "<span class=\"bold\">$t_last_updated</span>";
-			} else {
-				echo $t_last_updated;
-			}
-		?>
-	</td>
-	<td class="left" bgcolor="<?php echo $status_color ?>">
-		<span class="print"><?php echo $v_summary ?></a>
-	</td>
 </tr>
 <?php
 	} # isset_loop
@@ -303,5 +214,3 @@
 
 <input type="submit" class="button" value="<?php echo lang_get( 'hide_button' ) ?>" />
 </form>
-
-<?php # @@@ BUG ?  Where is the closing FORM tag??? ?>
