@@ -6,7 +6,7 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: print_all_bug_page_excel.php,v 1.42 2004/11/30 13:48:28 thraxisp Exp $
+	# $Id: print_all_bug_page_excel.php,v 1.51 2005/08/18 15:33:28 thraxisp Exp $
 	# --------------------------------------------------------
 ?>
 <?php
@@ -50,7 +50,7 @@
 
 	# This is where we used to do the entire actual filter ourselves
 	$t_page_number = gpc_get_int( 'page_number', 1 );
-	$t_per_page = null;
+	$t_per_page = -1;
 	$t_bug_count = null;
 	$t_page_count = null;
 
@@ -67,8 +67,9 @@
 
 	# get printing preferences
 	$t_user_id = auth_get_current_user_id();
+	$t_user_print_pref_table = config_get( 'mantis_user_print_pref_table' );
 	$query3 ="SELECT print_pref ".
-			"FROM $g_mantis_user_print_pref_table ".
+			"FROM $t_user_print_pref_table ".
 			"WHERE user_id='$t_user_id' ";
 
 	$result3 = db_query( $query3 );
@@ -98,7 +99,7 @@ xmlns="http://www.w3.org/TR/REC-html40">
 		if ( $f_type_page != 'html' ) {
 			for ( $i=0 ; $i <$field_name_count ; $i++ ) {
 				if ( isset( $t_prefs[$i] ) && ( 1 == $t_prefs[$i] ) ) {  ?>
-	<td class=xl2316681 style='border-left:none'><?php echo $t_field_name_arr[$i] ?></td>
+	<td class=xl2316681 style='border-left:none'><?php echo lang_get( $t_field_name_arr[$i] ) ?></td>
 <?php
 				} //if isset
 			} //for
@@ -111,55 +112,49 @@ xmlns="http://www.w3.org/TR/REC-html40">
 
 	$f_bug_arr = explode_enum_string( $f_export );
 
-	for( $i=0; $i < $row_count; $i++ ) {
-		if ( isset( $f_bug_arr[$i] ) ) {
-			$index = $f_bug_arr[$i];
-			$t_bug_arr_sort[$index]=1;
-		}
-	}
-
+	# @@debug var_dump($t_field_name_arr);
 	for( $i=0; $i < $row_count; $i++ ) {
 
 		# prefix bug data with v_
 		extract( $result[$i], EXTR_PREFIX_ALL, 'v' );
 
-		$t_last_updated = date( $g_short_date_format, $v_last_updated );
+		if ( in_array( $v_id, $f_bug_arr ) || ( $f_show_flag==0 ) ) {
+            $t_last_updated = date( $g_short_date_format, $v_last_updated );
 
-		# grab the bugnote count
-		$bugnote_count = bug_get_bugnote_count( $v_id );
+            # grab the bugnote count
+            $bugnote_count = bug_get_bugnote_count( $v_id );
 
-		# grab the project name
-		$project_name = project_get_field( $v_project_id, 'name' );
+            # grab the project name
+            $project_name = project_get_field( $v_project_id, 'name' );
 
-		$query4 = "SELECT *
-			FROM $g_mantis_bug_text_table
-			WHERE id='$v_bug_text_id'";
-		$result4 = db_query( $query4 );
-		$row = db_fetch_array( $result4 );
-		extract( $row, EXTR_PREFIX_ALL, 'v2' );
+            $t_bug_text_table = config_get( 'mantis_bug_text_table' );
+            $query4 = "SELECT *
+                FROM $t_bug_text_table
+                WHERE id='$v_bug_text_id'";
+            $result4 = db_query( $query4 );
+            $row = db_fetch_array( $result4 );
+            extract( $row, EXTR_PREFIX_ALL, 'v2' );
 
-		$v_os 						= string_display( $v_os );
-		$v_os_build					= string_display( $v_os_build );
-		$v_platform					= string_display( $v_platform );
-		$v_version 					= string_display( $v_version );
-		$v_summary 					= string_display_links( $v_summary );
+            $v_os 						= string_display( $v_os );
+            $v_os_build					= string_display( $v_os_build );
+            $v_platform					= string_display( $v_platform );
+            $v_version 					= string_display( $v_version );
+            $v_summary 					= string_display_links( $v_summary );
 
-		# line feeds are desactivated in case of excel export, to avoid multiple lines
-		if ( $f_type_page != 'html' ) {
+            # line feeds are desactivated in case of excel export, to avoid multiple lines
+            if ( $f_type_page != 'html' ) {
 				$v2_description = stripslashes( str_replace( '\n',' ',$v2_description ));
 				$v2_steps_to_reproduce  = stripslashes( str_replace( '\n',' ',$v2_steps_to_reproduce ) );
 				$v2_additional_information = stripslashes( str_replace( '\n',' ',$v2_additional_information ));
-		}
-		else {
-			$v2_description 			= string_display_links( $v2_description );
-			$v2_steps_to_reproduce 		= string_display_links( $v2_steps_to_reproduce );
-			$v2_additional_information 	= string_display_links( $v2_additional_information );
-		}
+            } else {
+                $v2_description 			= string_display_links( $v2_description );
+                $v2_steps_to_reproduce 		= string_display_links( $v2_steps_to_reproduce );
+                $v2_additional_information 	= string_display_links( $v2_additional_information );
+            }
 
-		# an index for incrementing the array position
-		$name_index=0;
+            # an index for incrementing the array position
+            $name_index=0;
 
-		if ( isset( $t_bug_arr_sort[$i] ) || ( $f_show_flag==0 ) ) {
 ?>
 <tr>
 	<?php if ( ( $name_index < $field_name_count ) && ( !isset( $t_prefs[$name_index] ) || ( 1 == $t_prefs[$name_index] ) ) ) { ?>
@@ -213,7 +208,9 @@ xmlns="http://www.w3.org/TR/REC-html40">
 
 	<?php if ( ( $name_index < $field_name_count ) && ( !isset( $t_prefs[$name_index] ) || ( 1 == $t_prefs[$name_index] ) ) ) { ?>
 	<td class=xl2216681 nowrap style='border-top:none;border-left:none'>
-	<?php print_user_with_subject( $v_handler_id, $v_id ) ;
+	<?php      if ( access_has_bug_level( config_get( 'view_handler_threshold' ), $v_id ) ) {
+				    print_user_with_subject( $v_handler_id, $v_id ); 
+                }
 		  echo "</td>";
 			}
 	$name_index++;  ?>
@@ -327,8 +324,9 @@ xmlns="http://www.w3.org/TR/REC-html40">
 	if ( ( $name_index < $field_name_count ) && ( !isset( $t_prefs[$name_index] ) || ( 1 == $t_prefs[$name_index] ) ) ) { ?>
 	<td class=xl2216681 nowrap style='border-top:none;border-left:none'>
 <?php
+        	$t_file_table = config_get( 'mantis_bug_file_table' );
 			$query5 = "SELECT filename, filesize, date_added
-					FROM $g_mantis_bug_file_table
+					FROM $t_file_table
 					WHERE bug_id='$v_id'";
 			$result5 = db_query( $query5 );
 			$num_files = db_num_rows( $result5 );
@@ -347,7 +345,7 @@ xmlns="http://www.w3.org/TR/REC-html40">
 					PRINT '<br />';
 				}
 				else {
-					PRINT '&nbsp';
+					PRINT ' ';
 				} #if
 			} #for loop
 
@@ -356,7 +354,7 @@ xmlns="http://www.w3.org/TR/REC-html40">
 	$name_index++;
 ?>
 <?php # Bugnotes BEGIN (3 rows) ?>
-<td colspan=3>
+<td colspan="3">
 <?php  # print bugnotes
 		# get the bugnote data
  		if ( !access_has_bug_level( config_get( 'private_bugnote_threshold' ), $v_id ) ) {
@@ -368,8 +366,8 @@ xmlns="http://www.w3.org/TR/REC-html40">
 		$t_bugnote_table		= config_get( 'mantis_bugnote_table' );
 		$t_bugnote_text_table	= config_get( 'mantis_bugnote_text_table' );
 		$t_bugnote_order = current_user_get_pref( 'bugnote_order' );
-		
-		$query6 = "SELECT *,date_submitted
+
+		$query6 = "SELECT *
 				FROM $t_bugnote_table
 				WHERE bug_id='$v_id' $t_restriction
 				ORDER BY date_submitted $t_bugnote_order";
@@ -445,7 +443,7 @@ xmlns="http://www.w3.org/TR/REC-html40">
 
 </tr>
 <?php
-		} #isset
+		} #in_array
 } #for loop
 ?>
 </table>
