@@ -6,18 +6,26 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: summary_graph_bypriority.php,v 1.14 2004/01/11 07:16:08 vboctor Exp $
+	# $Id: summary_graph_bypriority.php,v 1.16 2005/02/12 20:01:07 jlatour Exp $
 	# --------------------------------------------------------
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'graph_api.php' );
 
 	access_ensure_project_level( config_get( 'view_summary_threshold' ) );
 
-	create_bug_enum_summary( lang_get( 'priority_enum_string' ), 'priority');
-	graph_bug_enum_summary( lang_get( 'by_priority' ) );
-?>
\ No newline at end of file
+	$f_width = gpc_get_int( 'width', 300 );
+	$t_ar = config_get( 'graph_bar_aspect' );
+
+	$f_token = gpc_get_int( 'token', 0 );
+	if ( 0 == $f_token ) {
+		$t_metrics = create_bug_enum_summary( lang_get( 'priority_enum_string' ), 'priority');
+	} else {
+		$t_metrics = graph_total_metrics( unserialize( token_get_value( $f_token ) ) );
+	}
+	graph_bar( $t_metrics, lang_get( 'by_priority' ), $f_width, $f_width * $t_ar );
+?>
