@@ -6,25 +6,25 @@
 	# See the README and LICENSE files for details
 
 	# --------------------------------------------------------
-	# $Id: summary_graph_bystatus_pct.php,v 1.13 2004/01/11 07:16:08 vboctor Exp $
+	# $Id: summary_graph_bystatus_pct.php,v 1.15 2005/02/12 20:01:08 jlatour Exp $
 	# --------------------------------------------------------
 ?>
 <?php
 	require_once( 'core.php' );
-	
+
 	$t_core_path = config_get( 'core_path' );
-	
+
 	require_once( $t_core_path.'graph_api.php' );
 
 	access_ensure_project_level( config_get( 'view_summary_threshold' ) );
 
-	#centers the chart
-	$center = 0.3;
+	$f_width = gpc_get_int( 'width', 300 );
 
-	#position of the legend
-	$poshorizontal = 0.03;
-	$posvertical = 0.09;
-
-	create_bug_enum_summary_pct( lang_get( 'status_enum_string' ), 'status');
-	graph_bug_enum_summary_pct( lang_get( 'by_status_pct' ) );
-?>
\ No newline at end of file
+	$f_token = gpc_get_int( 'token', 0 );
+	if ( 0 == $f_token ) {
+		$t_metrics = create_bug_enum_summary( lang_get( 'status_enum_string' ), 'status' );
+	} else {
+		$t_metrics = unserialize( token_get_value( $f_token ) );
+	}
+	graph_pie( $t_metrics, lang_get( 'by_status_pct' ), $f_width, $f_width );
+?>
